function y=nwestim(X,Y,x_net,h,kernel)
% function y=nwestim(X,Y,x_net,h,kernel)
% Nadaraya - Watson estimator
% X,Y - data
% x_net - sit bodu pro vyhodnoceni
% h - sirka okna
% kernel - jadro, implicitne Epanecnikovo

if nargin<4
 error('nwmatrix: Too litle input parameters, sorry.');
 return;
end
if nargin==4
 kernel=K_def('epan');
end
Y=col(Y);
M=nwmatrix(X,h,x_net,kernel);
y=M*Y;
